package by.zerg.layouteditor.gui;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.filechooser.FileFilter;

import by.zerg.layouteditor.theme.Config;
import by.zerg.layouteditor.theme.Loader;
import by.zerg.layouteditor.theme.Theme;

public class EditorFrame extends JFrame {
	private String root;
	private JFileChooser fc;
	private JButton loadButton;
	private JButton saveButton;
	private JButton openButton;
	private JTextArea configArea;
	private JComboBox themesCombo;

	public EditorFrame() {
		fc = new JFileChooser("c:\\");
		fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		fc.setFileFilter(new FileFilter() {

			@Override
			public String getDescription() {
				return "PokerStars";
			}

			@Override
			public boolean accept(File f) {
				return f.isDirectory();
			}
		});

		ActionListener actionListener = new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent event) {
				String actionCommand = event.getActionCommand();
				if ("LOAD".equals(actionCommand)) {
					int returnVal = fc.showOpenDialog(null);
					if (returnVal == JFileChooser.APPROVE_OPTION) {
						File selected = fc.getSelectedFile();
						root = selected.getAbsolutePath();
						try {
							themesCombo.removeAllItems();
							configArea.setText(null);
							Loader.load(root);
							for (Theme theme : Loader.getDefaultThemes()) {
								themesCombo.addItem(theme);
								printTheme(theme);
							}
							for (Theme theme : Loader.getCustomThemes()) {
								themesCombo.addItem(theme);
								printTheme(theme);
							}
							configArea.setCaretPosition(0);
						} catch (Throwable t) {
							t.printStackTrace();
						}
					}
				} else if ("OPEN".equals(actionCommand)) {
					Theme theme = (Theme) themesCombo.getSelectedItem();
					try {
						Config config = theme.getConfig();
						config.open();
						configArea.setText(config.getData());
						configArea.setCaretPosition(0);
					} catch (Throwable t) {
						t.printStackTrace();
					}
				} else if ("SAVE".equals(actionCommand)) {
					Theme theme = (Theme) themesCombo.getSelectedItem();
					try {
						Config config = theme.getConfig();
						config.setData(configArea.getText());
						config.save();
					} catch (Throwable t) {
						t.printStackTrace();
					}
				}
			}
		};

		loadButton = createButton("Load", "LOAD", actionListener);
		openButton = createButton("Open", "OPEN", actionListener);
		saveButton = createButton("Save", "SAVE", actionListener);

		configArea = new JTextArea(20, 60);

		themesCombo = new JComboBox();
	}

	private void printTheme(Theme theme) {
		configArea.append("id:\t" + theme.getId() + "\nname:\t"
				+ theme.getName() + "\ncopyright:\t" + theme.getCopyright()
				+ "\nbase:\t" + theme.getBaseId() + "\nfolder:\t"
				+ theme.getFolder() + "\ndeck:\t" + theme.getDeck()
				+ "\nfeature:\t" + theme.getFeature() + "\nlobby:\t"
				+ theme.getLobby() + "\npreview:\t" + theme.getPreview()
				+ "\n\n");
	}

	private JButton createButton(String label, String actionCommand,
			ActionListener actionListener) {
		JButton newButton = new JButton(label);
		newButton.setActionCommand(actionCommand);
		newButton.addActionListener(actionListener);
		return newButton;
	}

	private void init() {
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setTitle("Layout Editor v1.0b by Hitman");
		setLayout(new BorderLayout());

		JPanel topPanel = new JPanel();
		topPanel.add(loadButton);
		topPanel.add(themesCombo);
		topPanel.add(openButton);
		topPanel.add(saveButton);
		add(topPanel, BorderLayout.NORTH);

		add(new JScrollPane(configArea), BorderLayout.SOUTH);

		pack();
		setLocationRelativeTo(null);
		setVisible(true);
	}

	public static void main(String[] args) {
		new EditorFrame().init();
	}
}
