package by.zerg.layouteditor.theme;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;

public class Loader {
	private static List<Theme> defaultThemes;
	private static List<Theme> customThemes;

	public static void load(String root) throws IOException {
		defaultThemes = new ArrayList<Theme>();
		customThemes = new ArrayList<Theme>();
		String defaultThemesRoot = root + "\\themes";
		String customThemesRoot = root + "\\xthemes";
		Config config = new Config(defaultThemesRoot + "\\themes.ini");
		config.open();
		String defaultThemesConfig = config.getData();
		parseConfig(defaultThemesConfig, defaultThemes, defaultThemesRoot);
		StringWriter writer = new StringWriter();
		FileInputStream fis = new FileInputStream(customThemesRoot
				+ "\\xthemes.ini");
		byte[] buff = new byte[1024];
		int len;
		while ((len = fis.read(buff)) > 0) {
			writer.write(new String(buff, 0, len));
		}
		fis.close();
		String customThemesConfig = writer.toString();
		writer.flush();
		writer.close();
		parseConfig(customThemesConfig, customThemes, customThemesRoot);
	}

	private static void parseConfig(String config, List<Theme> themes,
			String root) throws IOException {
		BufferedReader reader = new BufferedReader(new StringReader(config));
		String line = null;
		String id = null;
		String name = null;
		String copyright = null;
		String baseId = null;
		String folder = null;
		String deck = null;
		String feature = null;
		String lobby = null;
		String preview = null;
		boolean flag = false;
		while ((line = reader.readLine()) != null) {
			line = line.trim();
			if (line.startsWith("[") && line.endsWith("]")) {
				if (flag) {
					themes.add(new Theme(id, name, copyright, baseId, folder,
							deck, feature, lobby, preview));
					id = null;
					name = null;
					copyright = null;
					baseId = null;
					folder = null;
					deck = null;
					feature = null;
					lobby = null;
					preview = null;
				}
				flag = true;
				id = line.substring(1, line.length() - 1);
			} else if (line.startsWith("name=")) {
				name = line.substring(5);
			} else if (line.startsWith("copyright=")) {
				copyright = line.substring(10);
			} else if (line.startsWith("base=")) {
				baseId = line.substring(5);
			} else if (line.startsWith("folder=")) {
				folder = root + "\\" + line.substring(7);
			} else if (line.startsWith("deck=")) {
				deck = line.substring(5);
			} else if (line.startsWith("feature=")) {
				feature = line.substring(8);
			} else if (line.startsWith("lobby=")) {
				lobby = line.substring(6);
			} else if (line.startsWith("preview=")) {
				preview = line.substring(8);
			}
		}
		if (flag) {
			themes.add(new Theme(id, name, copyright, baseId, folder, deck,
					feature, lobby, preview));
		}
	}

	public static List<Theme> getDefaultThemes() {
		return defaultThemes;
	}

	public static List<Theme> getCustomThemes() {
		return customThemes;
	}
}
